options = {
    "newChannel": {
        "name": "",
        "id": 0,
        "type": "",
        "category": "",
        "categoryid": 0,
        "guild": "",
        "nsfw": "",
        "delay": 0,
        "created": ""
    },
    "oldChannel": {
        "name": "",
        "id": 0,
        "type": "",
        "category": "",
        "categoryid": 0,
        "guild": "",
        "nsfw": "",
        "delay": 0,
        "created": ""
    },
    "memberJoined": {
        "id": 0
    },
    "deletedChannel": {
        "name": "",
        "id": 0,
        "type": "",
        "category": "",
        "categoryid": 0,
        "guild": "",
        "nsfw": "",
        "delay": 0,
        "created": ""
    }
}
